@@ -6,13 +6,13 @@ use tracing::{error, info};
 
 const AUDIT_ENGINE: &str = "audit";
 
-pub struct Audit<'ranges> {
+pub struct Audit<'lock> {
     json: PathBuf,
-    lockfile: &'ranges Lockfile,
+    lockfile: &'lock Lockfile,
 }
 
-impl<'ranges> Audit<'ranges> {
-    pub fn new<P>(json: P, lockfile: &'ranges Lockfile) -> Self
+impl<'lock> Audit<'lock> {
+    pub fn new<P>(json: P, lockfile: &'lock Lockfile) -> Self
     where
         P: Into<PathBuf>,
     {
@@ -26,7 +26,7 @@ impl<'ranges> Audit<'ranges> {
     // it might be possible to use 'Cargo.lock' instead (or use 'cargo-deny' to obtain a graph of dependency and find the root dependency)
     fn to_issue(&self, vulnerability: &Vulnerability) -> sonar::Issue {
         let advisory = &vulnerability.advisory;
-        let rule_id = advisory.id.to_string();
+        let rule_id = format!("{}::{}", AUDIT_ENGINE, advisory.id);
         let message = format!(
             "{} (see https://github.com/rustsec/advisory-db/blob/main/crates/{}/{}.md)",
             advisory.title, advisory.package, advisory.id
