@@ -22,6 +22,12 @@ pub struct Command {
     #[cfg(feature = "deny")]
     #[clap(long, default_value = "deny.json")]
     pub deny_path: PathBuf,
+    #[cfg(feature = "outdated")]
+    #[clap(short, long)]
+    pub outdated: bool,
+    #[cfg(feature = "outdated")]
+    #[clap(long, default_value = "outdated.json")]
+    pub outdated_path: PathBuf,
     #[clap(short, long, default_value = "sonar.json")]
     pub sonar_path: PathBuf,
 }
