@@ -46,10 +46,12 @@ impl From<&DiagnosticSpan> for sonar::TextRange {
         Self {
             start_line: span.line_start,
             end_line: span.line_end,
-            start_column: span.column_start,
+            // FIXME: we should actually check is spans have a column bound on
+            // an line end and remove 1 if this is the case.
             // clippy does consider the end-of-line character
             // but sonar-scanner does not and check for validity
-            end_column: span.column_end - 1,
+            start_column: span.column_start.saturating_sub(1),
+            end_column: span.column_end.saturating_sub(1),
         }
     }
 }
