@@ -9,6 +9,8 @@ mod cli;
 mod clippy;
 #[cfg(feature = "deny")]
 mod deny;
+#[cfg(feature = "outdated")]
+mod outdated;
 mod sonar;
 
 use std::fs::File;
@@ -67,6 +69,13 @@ fn main() -> Result<()> {
         let deny_report: sonar::Report = Deny::new(options.deny_path, &lockfile).try_into()?;
         sonar_report.extend(deny_report);
     }
+    #[cfg(feature = "outdated")]
+    if options.outdated {
+        use crate::outdated::Outdated;
+        let outdated_report: sonar::Report =
+            Outdated::new(options.outdated_path, &lockfile).try_into()?;
+        sonar_report.extend(outdated_report);
+    }
     let file = File::create(options.sonar_path).context("failed to create 'sonar.json' file")?;
     info!("{} sonar issues created", sonar_report.len());
     #[cfg(not(debug_assertions))]
